@@ -43,13 +43,13 @@
 #include <unistd.h>
 #include <locale.h>
 
-#include <QtCore/QLibrary>
-#include <QtCore/QString>
-#include <QtCore/QFile>
-#include <QtCore/QDate>
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtCore/QRegExp>
+#include <QLibrary>
+#include <QString>
+#include <QFile>
+#include <QDate>
+#include <QDir>
+#include <QFileInfo>
+#include <QRegExp>
 #include <QFont>
 #include <kcrash.h>
 #include <kconfig.h>
@@ -165,7 +165,7 @@ static void cleanup_fds()
     int maxfd = FD_SETSIZE;
     struct rlimit rl;
     if (getrlimit(RLIMIT_NOFILE, &rl) == 0) {
-        maxfd = rl.rlim_max;
+        maxfd = rl.rlim_cur;
     }
     for (int fd = 3; fd < maxfd; ++fd) {
 #if KDEINIT_OOM_PROTECT
@@ -490,7 +490,8 @@ static pid_t launch(int argc, const char *_name, const char *args,
                                                QLatin1String(LIB_INSTALL_DIR "/libkdeinit5_")) + QLatin1String(".so");
             }
             // Don't confuse the user with "Could not load libkdeinit5_foo.so" if it doesn't exist
-            if (!QFile::exists(libpath)) {
+            // (and check for empty string to avoid warning message in QFileInfo::exists)
+            if (libpath.isEmpty() || !QFileInfo::exists(libpath)) {
                 libpath.clear();
             }
         }
